==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/ColumnCustomFilterConditionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnFilterConditionDescriptionMetadata } from "./ColumnFilterConditionDescriptionMetadata";
import { ColumnCustomFilterConditionDescription } from "./ColumnCustomFilterConditionDescription";
/**
 * @hidden
 */
export let ColumnCustomFilterConditionDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnCustomFilterConditionDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnCustomFilterConditionDescriptionMetadata.a == null) {
                ColumnCustomFilterConditionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnCustomFilterConditionDescriptionMetadata.c(ColumnCustomFilterConditionDescriptionMetadata.a);
            }
            if (a.j(ColumnCustomFilterConditionDescriptionMetadata.a)) {
                return;
            }
            a.y(ColumnCustomFilterConditionDescriptionMetadata.a);
        }
        static c(a) {
            ColumnFilterConditionDescriptionMetadata.c(a);
            a.item("ValueRef", "(w:Value,wf:Value)DataRef");
            a.item("Id", "(w:ID,wf:ID)String");
            a.item("Index", "Number:int");
        }
        static d(a) {
            ColumnCustomFilterConditionDescriptionMetadata.b(a);
            a.aa("ColumnCustomFilterCondition", () => new ColumnCustomFilterConditionDescription());
            a.z("ColumnCustomFilterCondition", ColumnCustomFilterConditionDescriptionMetadata.a);
        }
    }
    ColumnCustomFilterConditionDescriptionMetadata.$t = /*@__PURE__*/ markType(ColumnCustomFilterConditionDescriptionMetadata, 'ColumnCustomFilterConditionDescriptionMetadata');
    ColumnCustomFilterConditionDescriptionMetadata.a = null;
    return ColumnCustomFilterConditionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ColumnCustomFilterConditionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnFilterConditionDescriptionMetadata } from "./ColumnFilterConditionDescriptionMetadata";
import { ColumnCustomFilterConditionDescription } from "./ColumnCustomFilterConditionDescription";
/**
 * @hidden
 */
export let ColumnCustomFilterConditionDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnCustomFilterConditionDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnCustomFilterConditionDescriptionMetadata.a == null) {
                ColumnCustomFilterConditionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnCustomFilterConditionDescriptionMetadata.c(ColumnCustomFilterConditionDescriptionMetadata.a);
            }
            if (a.k(ColumnCustomFilterConditionDescriptionMetadata.a)) {
                return;
            }
            a.aa(ColumnCustomFilterConditionDescriptionMetadata.a);
        }
        static c(a) {
            ColumnFilterConditionDescriptionMetadata.c(a);
            a.item("ValueRef", "(w:Value,wf:Value)DataRef");
            a.item("Id", "(w:ID,wf:ID)String");
            a.item("Index", "Number:int");
        }
        static d(a) {
            ColumnCustomFilterConditionDescriptionMetadata.b(a);
            a.ac("ColumnCustomFilterCondition", () => new ColumnCustomFilterConditionDescription());
            a.ab("ColumnCustomFilterCondition", ColumnCustomFilterConditionDescriptionMetadata.a);
        }
    }
    ColumnCustomFilterConditionDescriptionMetadata.$t = /*@__PURE__*/ markType(ColumnCustomFilterConditionDescriptionMetadata, 'ColumnCustomFilterConditionDescriptionMetadata');
    ColumnCustomFilterConditionDescriptionMetadata.a = null;
    return ColumnCustomFilterConditionDescriptionMetadata;
})();
